/****************************************************************************
** Meta object code from reading C++ file 'addprinter.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../Common/vendor/addprinter.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'addprinter.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_AddPrinterTask_t {
    QByteArrayData data[8];
    char stringdata0[105];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_AddPrinterTask_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_AddPrinterTask_t qt_meta_stringdata_AddPrinterTask = {
    {
QT_MOC_LITERAL(0, 0, 14), // "AddPrinterTask"
QT_MOC_LITERAL(1, 15, 12), // "signalStatus"
QT_MOC_LITERAL(2, 28, 0), // ""
QT_MOC_LITERAL(3, 29, 17), // "slotInstallStatus"
QT_MOC_LITERAL(4, 47, 7), // "iStatus"
QT_MOC_LITERAL(5, 55, 17), // "slotDependsStatus"
QT_MOC_LITERAL(6, 73, 18), // "slotFixHplipStatus"
QT_MOC_LITERAL(7, 92, 12) // "slotWriteLog"

    },
    "AddPrinterTask\0signalStatus\0\0"
    "slotInstallStatus\0iStatus\0slotDependsStatus\0"
    "slotFixHplipStatus\0slotWriteLog"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_AddPrinterTask[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       5,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   39,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       3,    1,   42,    2, 0x09 /* Protected */,
       5,    1,   45,    2, 0x09 /* Protected */,
       6,    1,   48,    2, 0x09 /* Protected */,
       7,    1,   51,    2, 0x09 /* Protected */,

 // signals: parameters
    QMetaType::Void, QMetaType::Int,    2,

 // slots: parameters
    QMetaType::Void, QMetaType::Int,    4,
    QMetaType::Void, QMetaType::Int,    4,
    QMetaType::Void, QMetaType::Int,    4,
    QMetaType::Void, QMetaType::Int,    4,

       0        // eod
};

void AddPrinterTask::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<AddPrinterTask *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->signalStatus((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 1: _t->slotInstallStatus((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 2: _t->slotDependsStatus((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 3: _t->slotFixHplipStatus((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 4: _t->slotWriteLog((*reinterpret_cast< int(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (AddPrinterTask::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&AddPrinterTask::signalStatus)) {
                *result = 0;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject AddPrinterTask::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_AddPrinterTask.data,
    qt_meta_data_AddPrinterTask,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *AddPrinterTask::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AddPrinterTask::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_AddPrinterTask.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int AddPrinterTask::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void AddPrinterTask::signalStatus(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
